SDL: include: Renamed begin_code.h and close_code.h to have SDL_ prefixes.

From 31976323474e6399fb9b62c15bd6b0b7bb49fbae Mon Sep 17 00:00:00 2001
From: "Ryan C. Gordon" <[EMAIL REDACTED]>
Date: Thu, 22 Dec 2022 11:38:59 -0500
Subject: [PATCH] include: Renamed begin_code.h and close_code.h to have SDL_
 prefixes.

Fixes #6864.
---
 VisualC-GDK/SDL/SDL.vcxproj                   |  4 +-
 VisualC-GDK/SDL/SDL.vcxproj.filters           |  4 +-
 VisualC-WinRT/SDL-UWP.vcxproj                 |  4 +-
 VisualC-WinRT/SDL-UWP.vcxproj.filters         |  4 +-
 VisualC/SDL/SDL.vcxproj                       |  4 +-
 VisualC/SDL/SDL.vcxproj.filters               |  4 +-
 Xcode/SDL/SDL.xcodeproj/project.pbxproj       | 40 +++++++++----------
 docs/README-migration.md                      |  3 ++
 include/SDL3/SDL_assert.h                     |  4 +-
 include/SDL3/SDL_atomic.h                     |  4 +-
 include/SDL3/SDL_audio.h                      |  4 +-
 .../SDL3/{begin_code.h => SDL_begin_code.h}   | 10 ++---
 include/SDL3/SDL_bits.h                       |  4 +-
 include/SDL3/SDL_blendmode.h                  |  4 +-
 include/SDL3/SDL_clipboard.h                  |  4 +-
 .../SDL3/{close_code.h => SDL_close_code.h}   | 10 ++---
 include/SDL3/SDL_cpuinfo.h                    |  4 +-
 include/SDL3/SDL_endian.h                     |  4 +-
 include/SDL3/SDL_error.h                      |  4 +-
 include/SDL3/SDL_events.h                     |  4 +-
 include/SDL3/SDL_filesystem.h                 |  4 +-
 include/SDL3/SDL_gamecontroller.h             |  4 +-
 include/SDL3/SDL_guid.h                       |  4 +-
 include/SDL3/SDL_haptic.h                     |  4 +-
 include/SDL3/SDL_hidapi.h                     |  4 +-
 include/SDL3/SDL_hints.h                      |  4 +-
 include/SDL3/SDL_init.h                       |  4 +-
 include/SDL3/SDL_joystick.h                   |  4 +-
 include/SDL3/SDL_keyboard.h                   |  4 +-
 include/SDL3/SDL_loadso.h                     |  4 +-
 include/SDL3/SDL_locale.h                     |  4 +-
 include/SDL3/SDL_log.h                        |  4 +-
 include/SDL3/SDL_main.h                       |  4 +-
 include/SDL3/SDL_main_impl.h                  |  8 ++--
 include/SDL3/SDL_messagebox.h                 |  4 +-
 include/SDL3/SDL_metal.h                      |  4 +-
 include/SDL3/SDL_misc.h                       |  4 +-
 include/SDL3/SDL_mouse.h                      |  4 +-
 include/SDL3/SDL_mutex.h                      |  4 +-
 include/SDL3/SDL_pixels.h                     |  4 +-
 include/SDL3/SDL_platform.h                   |  4 +-
 include/SDL3/SDL_power.h                      |  4 +-
 include/SDL3/SDL_rect.h                       |  4 +-
 include/SDL3/SDL_render.h                     |  4 +-
 include/SDL3/SDL_rwops.h                      |  4 +-
 include/SDL3/SDL_sensor.h                     |  4 +-
 include/SDL3/SDL_shape.h                      |  4 +-
 include/SDL3/SDL_stdinc.h                     |  4 +-
 include/SDL3/SDL_surface.h                    |  4 +-
 include/SDL3/SDL_system.h                     |  4 +-
 include/SDL3/SDL_syswm.h                      |  4 +-
 include/SDL3/SDL_test.h                       |  4 +-
 include/SDL3/SDL_test_assert.h                |  4 +-
 include/SDL3/SDL_test_common.h                |  4 +-
 include/SDL3/SDL_test_compare.h               |  4 +-
 include/SDL3/SDL_test_crc32.h                 |  4 +-
 include/SDL3/SDL_test_font.h                  |  4 +-
 include/SDL3/SDL_test_fuzzer.h                |  4 +-
 include/SDL3/SDL_test_harness.h               |  4 +-
 include/SDL3/SDL_test_images.h                |  4 +-
 include/SDL3/SDL_test_log.h                   |  4 +-
 include/SDL3/SDL_test_md5.h                   |  4 +-
 include/SDL3/SDL_test_memory.h                |  4 +-
 include/SDL3/SDL_test_random.h                |  4 +-
 include/SDL3/SDL_thread.h                     |  4 +-
 include/SDL3/SDL_timer.h                      |  4 +-
 include/SDL3/SDL_touch.h                      |  4 +-
 include/SDL3/SDL_version.h                    |  4 +-
 include/SDL3/SDL_video.h                      |  4 +-
 include/SDL3/SDL_vulkan.h                     |  4 +-
 70 files changed, 167 insertions(+), 164 deletions(-)
 rename include/SDL3/{begin_code.h => SDL_begin_code.h} (96%)
 rename include/SDL3/{close_code.h => SDL_close_code.h} (85%)

diff --git a/VisualC-GDK/SDL/SDL.vcxproj b/VisualC-GDK/SDL/SDL.vcxproj
index b90fd808d70b..5db711b5c8ea 100644
--- a/VisualC-GDK/SDL/SDL.vcxproj
+++ b/VisualC-GDK/SDL/SDL.vcxproj
@@ -288,8 +288,8 @@
     </Link>
   </ItemDefinitionGroup>
   <ItemGroup>
-    <ClInclude Include="..\..\include\SDL3\begin_code.h" />
-    <ClInclude Include="..\..\include\SDL3\close_code.h" />
+    <ClInclude Include="..\..\include\SDL3\SDL_begin_code.h" />
+    <ClInclude Include="..\..\include\SDL3\SDL_close_code.h" />
     <ClInclude Include="..\..\include\SDL3\SDL.h" />
     <ClInclude Include="..\..\include\SDL3\SDL_assert.h" />
     <ClInclude Include="..\..\include\SDL3\SDL_atomic.h" />
diff --git a/VisualC-GDK/SDL/SDL.vcxproj.filters b/VisualC-GDK/SDL/SDL.vcxproj.filters
index 710ae82fadc6..b678ddd8290b 100644
--- a/VisualC-GDK/SDL/SDL.vcxproj.filters
+++ b/VisualC-GDK/SDL/SDL.vcxproj.filters
@@ -174,10 +174,10 @@
     </Filter>
   </ItemGroup>
   <ItemGroup>
-    <ClInclude Include="..\..\include\SDL3\begin_code.h">
+    <ClInclude Include="..\..\include\SDL3\SDL_begin_code.h">
       <Filter>API Headers</Filter>
     </ClInclude>
-    <ClInclude Include="..\..\include\SDL3\close_code.h">
+    <ClInclude Include="..\..\include\SDL3\SDL_close_code.h">
       <Filter>API Headers</Filter>
     </ClInclude>
     <ClInclude Include="..\..\include\SDL3\SDL.h">
diff --git a/VisualC-WinRT/SDL-UWP.vcxproj b/VisualC-WinRT/SDL-UWP.vcxproj
index 09e22b53a1c4..3fdbef4fb949 100644
--- a/VisualC-WinRT/SDL-UWP.vcxproj
+++ b/VisualC-WinRT/SDL-UWP.vcxproj
@@ -35,8 +35,8 @@
     </ProjectConfiguration>
   </ItemGroup>
   <ItemGroup>
-    <ClInclude Include="..\include\SDL3\begin_code.h" />
-    <ClInclude Include="..\include\SDL3\close_code.h" />
+    <ClInclude Include="..\include\SDL3\SDL_begin_code.h" />
+    <ClInclude Include="..\include\SDL3\SDL_close_code.h" />
     <ClInclude Include="..\include\SDL3\SDL.h" />
     <ClInclude Include="..\include\SDL3\SDL_assert.h" />
     <ClInclude Include="..\include\SDL3\SDL_atomic.h" />
diff --git a/VisualC-WinRT/SDL-UWP.vcxproj.filters b/VisualC-WinRT/SDL-UWP.vcxproj.filters
index 65dd7e2f2ba2..6e48a0ef4303 100644
--- a/VisualC-WinRT/SDL-UWP.vcxproj.filters
+++ b/VisualC-WinRT/SDL-UWP.vcxproj.filters
@@ -9,10 +9,10 @@
     </Filter>
   </ItemGroup>
   <ItemGroup>
-    <ClInclude Include="..\include\SDL3\begin_code.h">
+    <ClInclude Include="..\include\SDL3\SDL_begin_code.h">
       <Filter>Header Files</Filter>
     </ClInclude>
-    <ClInclude Include="..\include\SDL3\close_code.h">
+    <ClInclude Include="..\include\SDL3\SDL_close_code.h">
       <Filter>Header Files</Filter>
     </ClInclude>
     <ClInclude Include="..\include\SDL3\SDL.h">
diff --git a/VisualC/SDL/SDL.vcxproj b/VisualC/SDL/SDL.vcxproj
index c4e076b31687..8d55da2a4fe8 100644
--- a/VisualC/SDL/SDL.vcxproj
+++ b/VisualC/SDL/SDL.vcxproj
@@ -234,8 +234,8 @@
     </Link>
   </ItemDefinitionGroup>
   <ItemGroup>
-    <ClInclude Include="..\..\include\SDL3\begin_code.h" />
-    <ClInclude Include="..\..\include\SDL3\close_code.h" />
+    <ClInclude Include="..\..\include\SDL3\SDL_begin_code.h" />
+    <ClInclude Include="..\..\include\SDL3\SDL_close_code.h" />
     <ClInclude Include="..\..\include\SDL3\SDL.h" />
     <ClInclude Include="..\..\include\SDL3\SDL_assert.h" />
     <ClInclude Include="..\..\include\SDL3\SDL_atomic.h" />
diff --git a/VisualC/SDL/SDL.vcxproj.filters b/VisualC/SDL/SDL.vcxproj.filters
index 0dcef11b8d5a..738543acb456 100644
--- a/VisualC/SDL/SDL.vcxproj.filters
+++ b/VisualC/SDL/SDL.vcxproj.filters
@@ -171,10 +171,10 @@
     </Filter>
   </ItemGroup>
   <ItemGroup>
-    <ClInclude Include="..\..\include\SDL3\begin_code.h">
+    <ClInclude Include="..\..\include\SDL3\SDL_begin_code.h">
       <Filter>API Headers</Filter>
     </ClInclude>
-    <ClInclude Include="..\..\include\SDL3\close_code.h">
+    <ClInclude Include="..\..\include\SDL3\SDL_close_code.h">
       <Filter>API Headers</Filter>
     </ClInclude>
     <ClInclude Include="..\..\include\SDL3\SDL.h">
diff --git a/Xcode/SDL/SDL.xcodeproj/project.pbxproj b/Xcode/SDL/SDL.xcodeproj/project.pbxproj
index dc75ce7cbee5..b6e93c592e05 100644
--- a/Xcode/SDL/SDL.xcodeproj/project.pbxproj
+++ b/Xcode/SDL/SDL.xcodeproj/project.pbxproj
@@ -3444,18 +3444,18 @@
 		F3F7D9D62933074E00816151 /* SDL_version.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E42933074D00816151 /* SDL_version.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9D72933074E00816151 /* SDL_version.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E42933074D00816151 /* SDL_version.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9D82933074E00816151 /* SDL_version.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E42933074D00816151 /* SDL_version.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9D92933074E00816151 /* close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9DA2933074E00816151 /* close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9DB2933074E00816151 /* close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9DC2933074E00816151 /* close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9D92933074E00816151 /* SDL_close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* SDL_close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9DA2933074E00816151 /* SDL_close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* SDL_close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9DB2933074E00816151 /* SDL_close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* SDL_close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9DC2933074E00816151 /* SDL_close_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E52933074D00816151 /* SDL_close_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9DD2933074E00816151 /* SDL_mutex.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E62933074E00816151 /* SDL_mutex.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9DE2933074E00816151 /* SDL_mutex.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E62933074E00816151 /* SDL_mutex.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9DF2933074E00816151 /* SDL_mutex.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E62933074E00816151 /* SDL_mutex.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9E02933074E00816151 /* SDL_mutex.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E62933074E00816151 /* SDL_mutex.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9E12933074E00816151 /* begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9E22933074E00816151 /* begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9E32933074E00816151 /* begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		F3F7D9E42933074E00816151 /* begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9E12933074E00816151 /* SDL_begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* SDL_begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9E22933074E00816151 /* SDL_begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* SDL_begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9E32933074E00816151 /* SDL_begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* SDL_begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		F3F7D9E42933074E00816151 /* SDL_begin_code.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E72933074E00816151 /* SDL_begin_code.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9E52933074E00816151 /* SDL_system.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E82933074E00816151 /* SDL_system.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9E62933074E00816151 /* SDL_system.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E82933074E00816151 /* SDL_system.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		F3F7D9E72933074E00816151 /* SDL_system.h in Headers */ = {isa = PBXBuildFile; fileRef = F3F7D8E82933074E00816151 /* SDL_system.h */; settings = {ATTRIBUTES = (Public, ); }; };
@@ -3966,9 +3966,9 @@
 		F3F7D8E22933074D00816151 /* SDL_rect.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SDL_rect.h; path = SDL3/SDL_rect.h; sourceTree = "<group>"; };
 		F3F7D8E32933074D00816151 /* SDL_copying.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SDL_copying.h; path = SDL3/SDL_copying.h; sourceTree = "<group>"; };
 		F3F7D8E42933074D00816151 /* SDL_version.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SDL_version.h; path = SDL3/SDL_version.h; sourceTree = "<group>"; };
-		F3F7D8E52933074D00816151 /* close_code.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = close_code.h; path = SDL3/close_code.h; sourceTree = "<group>"; };
+		F3F7D8E52933074D00816151 /* SDL_close_code.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SDL_close_code.h; path = SDL3/SDL_close_code.h; sourceTree = "<group>"; };
 		F3F7D8E62933074E00816151 /* SDL_mutex.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SDL_mutex.h; path = SDL3/SDL_mutex.h; sourceTree = "<group>"; };
-		F3F7D8E72933074E00816151 /* begin_code.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = begin_code.h; path = SDL3/begin_code.h; sourceTree = "<group>"; };
+		F3F7D8E72933074E00816151 /* SDL_begin_code.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SDL_begin_code.h; path = SDL3/SDL_begin_code.h; sourceTree = "<group>"; };
 		F3F7D8E82933074E00816151 /* SDL_system.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SDL_system.h; path = SDL3/SDL_system.h; sourceTree = "<group>"; };
 		F59C710300D5CB5801000001 /* ReadMe.txt */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = text; path = ReadMe.txt; sourceTree = "<group>"; };
 		F59C710600D5CB5801000001 /* SDL.info */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = text; path = SDL.info; sourceTree = "<group>"; };
@@ -4133,8 +4133,8 @@
 		0153844A006D81B07F000001 /* Public Headers */ = {
 			isa = PBXGroup;
 			children = (
-				F3F7D8E72933074E00816151 /* begin_code.h */,
-				F3F7D8E52933074D00816151 /* close_code.h */,
+				F3F7D8E72933074E00816151 /* SDL_begin_code.h */,
+				F3F7D8E52933074D00816151 /* SDL_close_code.h */,
 				F3F7D8E02933074D00816151 /* SDL_assert.h */,
 				F3F7D8B92933074A00816151 /* SDL_atomic.h */,
 				F3F7D8AA2933074900816151 /* SDL_audio.h */,
@@ -5858,9 +5858,9 @@
 				A7D8BBAC23E2514500DCD162 /* SDL_windowevents_c.h in Headers */,
 				A7D8B3B123E2514200DCD162 /* SDL_yuv_c.h in Headers */,
 				A7D8B9CC23E2514400DCD162 /* SDL_yuv_sw_c.h in Headers */,
-				F3F7D9E22933074E00816151 /* begin_code.h in Headers */,
+				F3F7D9E22933074E00816151 /* SDL_begin_code.h in Headers */,
 				A7D8BB4623E2514500DCD162 /* blank_cursor.h in Headers */,
-				F3F7D9DA2933074E00816151 /* close_code.h in Headers */,
+				F3F7D9DA2933074E00816151 /* SDL_close_code.h in Headers */,
 				A7D8B5B823E2514300DCD162 /* controller_type.h in Headers */,
 				A7D8BB4C23E2514500DCD162 /* default_cursor.h in Headers */,
 				A7D8B23D23E2514200DCD162 /* egl.h in Headers */,
@@ -6086,9 +6086,9 @@
 				A7D8BBAD23E2514500DCD162 /* SDL_windowevents_c.h in Headers */,
 				A7D8B3B223E2514200DCD162 /* SDL_yuv_c.h in Headers */,
 				A7D8B9CD23E2514400DCD162 /* SDL_yuv_sw_c.h in Headers */,
-				F3F7D9E32933074E00816151 /* begin_code.h in Headers */,
+				F3F7D9E32933074E00816151 /* SDL_begin_code.h in Headers */,
 				A7D8BB4723E2514500DCD162 /* blank_cursor.h in Headers */,
-				F3F7D9DB2933074E00816151 /* close_code.h in Headers */,
+				F3F7D9DB2933074E00816151 /* SDL_close_code.h in Headers */,
 				A7D8B5B923E2514300DCD162 /* controller_type.h in Headers */,
 				A7D8BB4D23E2514500DCD162 /* default_cursor.h in Headers */,
 				A7D8B23E23E2514200DCD162 /* egl.h in Headers */,
@@ -6479,9 +6479,9 @@
 				A7D8BBAB23E2514500DCD162 /* SDL_windowevents_c.h in Headers */,
 				A7D8B3B023E2514200DCD162 /* SDL_yuv_c.h in Headers */,
 				A7D8B9CB23E2514400DCD162 /* SDL_yuv_sw_c.h in Headers */,
-				F3F7D9E12933074E00816151 /* begin_code.h in Headers */,
+				F3F7D9E12933074E00816151 /* SDL_begin_code.h in Headers */,
 				A7D8BB4523E2514500DCD162 /* blank_cursor.h in Headers */,
-				F3F7D9D92933074E00816151 /* close_code.h in Headers */,
+				F3F7D9D92933074E00816151 /* SDL_close_code.h in Headers */,
 				A7D8B5B723E2514300DCD162 /* controller_type.h in Headers */,
 				A7D8BB4B23E2514500DCD162 /* default_cursor.h in Headers */,
 				A7D8B23C23E2514200DCD162 /* egl.h in Headers */,
@@ -6920,8 +6920,8 @@
 				F3F7D9D82933074E00816151 /* SDL_version.h in Headers */,
 				F3F7D95C2933074E00816151 /* SDL_video.h in Headers */,
 				F3F7D9982933074E00816151 /* SDL_vulkan.h in Headers */,
-				F3F7D9E42933074E00816151 /* begin_code.h in Headers */,
-				F3F7D9DC2933074E00816151 /* close_code.h in Headers */,
+				F3F7D9E42933074E00816151 /* SDL_begin_code.h in Headers */,
+				F3F7D9DC2933074E00816151 /* SDL_close_code.h in Headers */,
 			);
 			runOnlyForDeploymentPostprocessing = 0;
 		};
diff --git a/docs/README-migration.md b/docs/README-migration.md
index 504140a6366f..a17d923eb036 100644
--- a/docs/README-migration.md
+++ b/docs/README-migration.md
@@ -29,6 +29,9 @@ The SDL3test library has been renamed SDL3_test.
 There is no static SDLmain library anymore, it's now header-only, see below in the SDL_main.h section.
 
 
+begin_code.h and close_code.h in the public headers have been renamed to SDL_begin_code.h and SDL_close_code.h. These aren't meant to be included directly by applications, but if your application did, please update your `#include` lines.
+
+
 ## SDL_cpuinfo.h
 
 The following headers are no longer automatically included, and will need to be included manually:
diff --git a/include/SDL3/SDL_assert.h b/include/SDL3/SDL_assert.h
index 40e41305ef3f..168140947648 100644
--- a/include/SDL3/SDL_assert.h
+++ b/include/SDL3/SDL_assert.h
@@ -24,7 +24,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -313,7 +313,7 @@ extern DECLSPEC void SDLCALL SDL_ResetAssertionReport(void);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_assert_h_ */
 
diff --git a/include/SDL3/SDL_atomic.h b/include/SDL3/SDL_atomic.h
index a4bc3fea19a7..8989529ed9a9 100644
--- a/include/SDL3/SDL_atomic.h
+++ b/include/SDL3/SDL_atomic.h
@@ -62,7 +62,7 @@
 #include <SDL3/SDL_stdinc.h>
 #include <SDL3/SDL_platform.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
@@ -403,7 +403,7 @@ extern DECLSPEC void* SDLCALL SDL_AtomicGetPtr(void **a);
 }
 #endif
 
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_atomic_h_ */
 
diff --git a/include/SDL3/SDL_audio.h b/include/SDL3/SDL_audio.h
index ee6cea02c8d4..2a89223bbbbb 100644
--- a/include/SDL3/SDL_audio.h
+++ b/include/SDL3/SDL_audio.h
@@ -37,7 +37,7 @@
 #include <SDL3/SDL_thread.h>
 #include <SDL3/SDL_rwops.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -1493,7 +1493,7 @@ extern DECLSPEC void SDLCALL SDL_CloseAudioDevice(SDL_AudioDeviceID dev);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_audio_h_ */
 
diff --git a/include/SDL3/SDL_bits.h b/include/SDL3/SDL_bits.h
index 34a51aa6fb3b..d30c67b34741 100644
--- a/include/SDL3/SDL_bits.h
+++ b/include/SDL3/SDL_bits.h
@@ -30,7 +30,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -119,7 +119,7 @@ SDL_HasExactlyOneBitSet32(Uint32 x)
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_bits_h_ */
 
diff --git a/include/SDL3/SDL_blendmode.h b/include/SDL3/SDL_blendmode.h
index ffe96916a1e3..8a9d67b569cf 100644
--- a/include/SDL3/SDL_blendmode.h
+++ b/include/SDL3/SDL_blendmode.h
@@ -28,7 +28,7 @@
 #ifndef SDL_blendmode_h_
 #define SDL_blendmode_h_
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -191,7 +191,7 @@ extern DECLSPEC SDL_BlendMode SDLCALL SDL_ComposeCustomBlendMode(SDL_BlendFactor
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_blendmode_h_ */
 
diff --git a/include/SDL3/SDL_clipboard.h b/include/SDL3/SDL_clipboard.h
index 7cbd812a5c75..cd9b33decceb 100644
--- a/include/SDL3/SDL_clipboard.h
+++ b/include/SDL3/SDL_clipboard.h
@@ -30,7 +30,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -134,7 +134,7 @@ extern DECLSPEC SDL_bool SDLCALL SDL_HasPrimarySelectionText(void);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_clipboard_h_ */
 
diff --git a/include/SDL3/close_code.h b/include/SDL3/SDL_close_code.h
similarity index 85%
rename from include/SDL3/close_code.h
rename to include/SDL3/SDL_close_code.h
index dc73432f6228..7ebccc81d95d 100644
--- a/include/SDL3/close_code.h
+++ b/include/SDL3/SDL_close_code.h
@@ -20,16 +20,16 @@
 */
 
 /**
- *  \file close_code.h
+ *  \file SDL_close_code.h
  *
- *  This file reverses the effects of begin_code.h and should be included
+ *  This file reverses the effects of SDL_begin_code.h and should be included
  *  after you finish any function and structure declarations in your headers
  */
 
-#ifndef _begin_code_h
-#error close_code.h included without matching begin_code.h
+#ifndef _SDL_begin_code_h
+#error SDL_close_code.h included without matching SDL_begin_code.h
 #endif
-#undef _begin_code_h
+#undef _SDL_begin_code_h
 
 /* Reset structure packing at previous byte alignment */
 #if defined(_MSC_VER) || defined(__MWERKS__) || defined(__BORLANDC__)
diff --git a/include/SDL3/SDL_cpuinfo.h b/include/SDL3/SDL_cpuinfo.h
index ee5be8eb63f1..0905b09d0785 100644
--- a/include/SDL3/SDL_cpuinfo.h
+++ b/include/SDL3/SDL_cpuinfo.h
@@ -30,7 +30,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -493,7 +493,7 @@ extern DECLSPEC void SDLCALL SDL_SIMDFree(void *ptr);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_cpuinfo_h_ */
 
diff --git a/include/SDL3/SDL_endian.h b/include/SDL3/SDL_endian.h
index 7f8be9142311..6a4d11a290c2 100644
--- a/include/SDL3/SDL_endian.h
+++ b/include/SDL3/SDL_endian.h
@@ -110,7 +110,7 @@ _m_prefetch(void *__P)
 #endif /* !SDL_FLOATWORDORDER */
 
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -341,7 +341,7 @@ SDL_SwapFloat(float x)
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_endian_h_ */
 
diff --git a/include/SDL3/SDL_error.h b/include/SDL3/SDL_error.h
index acbbeaa0d383..ee1e549ef6ff 100644
--- a/include/SDL3/SDL_error.h
+++ b/include/SDL3/SDL_error.h
@@ -30,7 +30,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -156,7 +156,7 @@ extern DECLSPEC int SDLCALL SDL_Error(SDL_errorcode code);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_error_h_ */
 
diff --git a/include/SDL3/SDL_events.h b/include/SDL3/SDL_events.h
index 13993f99178c..0907ed2d5316 100644
--- a/include/SDL3/SDL_events.h
+++ b/include/SDL3/SDL_events.h
@@ -38,7 +38,7 @@
 #include <SDL3/SDL_quit.h>
 #include <SDL3/SDL_touch.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -1143,7 +1143,7 @@ extern DECLSPEC Uint32 SDLCALL SDL_RegisterEvents(int numevents);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_events_h_ */
 
diff --git a/include/SDL3/SDL_filesystem.h b/include/SDL3/SDL_filesystem.h
index bba7aee50ab3..429398b4e8dd 100644
--- a/include/SDL3/SDL_filesystem.h
+++ b/include/SDL3/SDL_filesystem.h
@@ -30,7 +30,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
@@ -142,7 +142,7 @@ extern DECLSPEC char *SDLCALL SDL_GetPrefPath(const char *org, const char *app);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_filesystem_h_ */
 
diff --git a/include/SDL3/SDL_gamecontroller.h b/include/SDL3/SDL_gamecontroller.h
index d4323bc62dbe..b340f4178732 100644
--- a/include/SDL3/SDL_gamecontroller.h
+++ b/include/SDL3/SDL_gamecontroller.h
@@ -34,7 +34,7 @@
 #include <SDL3/SDL_sensor.h>
 #include <SDL3/SDL_joystick.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -1048,7 +1048,7 @@ extern DECLSPEC const char* SDLCALL SDL_GameControllerGetAppleSFSymbolsNameForAx
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_gamecontroller_h_ */
 
diff --git a/include/SDL3/SDL_guid.h b/include/SDL3/SDL_guid.h
index b4383cad5003..dea68fd5c38b 100644
--- a/include/SDL3/SDL_guid.h
+++ b/include/SDL3/SDL_guid.h
@@ -31,7 +31,7 @@
 #include <SDL3/SDL_stdinc.h>
 #include <SDL3/SDL_error.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -93,7 +93,7 @@ extern DECLSPEC SDL_GUID SDLCALL SDL_GUIDFromString(const char *pchGUID);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_guid_h_ */
 
diff --git a/include/SDL3/SDL_haptic.h b/include/SDL3/SDL_haptic.h
index 38ef69fa3ae7..846e16977792 100644
--- a/include/SDL3/SDL_haptic.h
+++ b/include/SDL3/SDL_haptic.h
@@ -111,7 +111,7 @@
 #include <SDL3/SDL_error.h>
 #include <SDL3/SDL_joystick.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -1334,7 +1334,7 @@ extern DECLSPEC int SDLCALL SDL_HapticRumbleStop(SDL_Haptic * haptic);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_haptic_h_ */
 
diff --git a/include/SDL3/SDL_hidapi.h b/include/SDL3/SDL_hidapi.h
index 968e7091c49c..b4d13010b864 100644
--- a/include/SDL3/SDL_hidapi.h
+++ b/include/SDL3/SDL_hidapi.h
@@ -64,7 +64,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -444,7 +444,7 @@ extern DECLSPEC void SDLCALL SDL_hid_ble_scan(SDL_bool active);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_hidapi_h_ */
 
diff --git a/include/SDL3/SDL_hints.h b/include/SDL3/SDL_hints.h
index 6274a12194bc..2f6e7aa1b7ff 100644
--- a/include/SDL3/SDL_hints.h
+++ b/include/SDL3/SDL_hints.h
@@ -41,7 +41,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
 extern "C" {
@@ -2549,7 +2549,7 @@ extern DECLSPEC void SDLCALL SDL_ClearHints(void);
 #ifdef __cplusplus
 }
 #endif
-#include <SDL3/close_code.h>
+#include <SDL3/SDL_close_code.h>
 
 #endif /* SDL_hints_h_ */
 
diff --git a/include/SDL3/SDL_init.h b/include/SDL3/SDL_init.h
index 7e4abbcddbcb..4b9962908e1a 100644
--- a/include/SDL3/SDL_init.h
+++ b/include/SDL3/SDL_init.h
@@ -30,7 +30,7 @@
 
 #include <SDL3/SDL_stdinc.h>
 
-#include <SDL3/begin_code.h>
+#include <SDL3/SDL_begin_code.h>
 /* Set up for C function definitions, even

(Patch may be truncated, please check the link at the top of this post.)
diff --git a/include/SDL3/begin_code.h b/include/SDL3/SDL_begin_code.h
similarity index 96%
rename from include/SDL3/begin_code.h
rename to include/SDL3/SDL_begin_code.h
index 0b23b57e286b..0bebddde5e1f 100644
--- a/include/SDL3/begin_code.h
+++ b/include/SDL3/SDL_begin_code.h
@@ -20,7 +20,7 @@
 */
 
 /**
- *  \file begin_code.h
+ *  \file SDL_begin_code.h
  *
  *  This file sets things up for C dynamic library function definitions,
  *  static inlined functions, and structures aligned at 4-byte alignment.
@@ -28,10 +28,10 @@
  */
 
 /* This shouldn't be nested -- included it around code only. */
 #ifdef _begin_code_h
 #error Nested inclusion of begin_code.h
 #endif
-#define _begin_code_h
+#define _SDL_begin_code_h
 
 #ifndef SDL_DEPRECATED
 #  if defined(__GNUC__) && (__GNUC__ >= 4)  /* technically, this arrived in gcc 3.1, but oh well. */
@@ -78,7 +78,7 @@
 /* Force structure packing at 4 byte alignment.
    This is necessary if the header is included in code which has structure
    packing set to an alternate value, say for loading structures from disk.
-   The packing is reset to the previous value in close_code.h
+   The packing is reset to the previous value in SDL_close_code.h
  */
 #if defined(_MSC_VER) || defined(__MWERKS__) || defined(__BORLANDC__)
 #ifdef _MSC_VER
@@ -28,10 +28,10 @@
 
 /* This shouldn't be nested -- included it around code only. */
-#ifdef _begin_code_h
-#error Nested inclusion of begin_code.h
+#ifdef _SDL_begin_code_h
+#error Nested inclusion of SDL_begin_code.h
 #endif